@@ -1,7 +1,7 @@
 package Mojolicious::Sessions;
 use Mojo::Base -base;
 
-use Mojo::JSON;
+use Mojo::JSON qw(encode_json j);
 use Mojo::Util qw(b64_decode b64_encode);
 
 has [qw(cookie_domain secure)];
@@ -14,7 +14,7 @@ sub load {
 
   return unless my $value = $c->signed_cookie($self->cookie_name);
   $value =~ s/-/=/g;
-  return unless my $session = Mojo::JSON->new->decode(b64_decode $value);
+  return unless my $session = j(b64_decode $value);
 
   # "expiration" value is inherited
   my $expiration = $session->{expiration} // $self->default_expiration;
@@ -47,7 +47,7 @@ sub store {
   $session->{expires} = $default || time + $expiration
     if $expiration || $default;
 
-  my $value = b64_encode(Mojo::JSON->new->encode($session), '');
+  my $value = b64_encode(encode_json($session), '');
   $value =~ s/=/-/g;
   my $options = {
     domain   => $self->cookie_domain,
@@ -129,8 +129,8 @@ C<expiration> and C<expires> session values.
 
 =head2 secure
 
-  my $secure = $sessions->secure;
-  $sessions  = $sessions->secure(1);
+  my $bool  = $sessions->secure;
+  $sessions = $sessions->secure($bool);
 
 Set the secure flag on all session cookies, so that browsers send them only
 over HTTPS connections.
